@@ -8,6 +8,10 @@ import binascii
 from dataclasses import dataclass
 from typing import Any, List, Optional, Type, Union
 
+from graphql.type import GraphQLResolveInfo
+
+from swh.graphql.backends.archive import Archive
+from swh.graphql.backends.search import Search
 from swh.graphql.errors import PaginationError
 from swh.graphql.utils import utils
 from swh.storage.interface import PagedResult
@@ -27,6 +31,12 @@ class ConnectionEdge:
     cursor: Optional[str]
 
 
+@dataclass
+class ConnectionData:
+    paged_result: PagedResult
+    total_count: Optional[int] = None
+
+
 class BaseConnection(ABC):
     """
     Base resolver for all the connections
@@ -36,11 +46,14 @@ class BaseConnection(ABC):
     _page_size: int = 50  # default page size (default value for the first arg)
     _max_page_size: int = 1000  # maximum page size(max value for the first arg)
 
-    def __init__(self, obj, info, paged_data=None, **kwargs):
-        self.obj: Optional[Any] = obj
-        self.info = info
+    def __init__(self, obj, info, data=None, **kwargs):
+        self.obj: Optional[BaseNode] = obj
+        self.info: GraphQLResolveInfo = info
+        self._connection_data: ConnectionData = data
         self.kwargs = kwargs
-        self._paged_data: PagedResult = paged_data
+        # initialize commonly used vars
+        self.archive = Archive()
+        self.search = Search()
 
     @property
     def edges(self) -> List[ConnectionEdge]:
@@ -65,16 +78,18 @@ class BaseConnection(ABC):
                 self._node_class(
                     obj=self, info=self.info, node_data=result, **self.kwargs
                 )
-                for result in self.get_paged_data().results
+                for result in self.get_connection_data().paged_result.results
             ]
-        return self.get_paged_data().results
+        return self.get_connection_data().paged_result.results
 
     @property
     def pageInfo(self) -> PageInfo:  # To support the schema naming convention
         # FIXME, add more details like startCursor
         return PageInfo(
-            hasNextPage=bool(self.get_paged_data().next_page_token),
-            endCursor=utils.get_encoded_cursor(self.get_paged_data().next_page_token),
+            hasNextPage=bool(self.get_connection_data().paged_result.next_page_token),
+            endCursor=utils.get_encoded_cursor(
+                self.get_connection_data().paged_result.next_page_token
+            ),
         )
 
     @property
@@ -83,29 +98,25 @@ class BaseConnection(ABC):
         Will be None for most of the connections
         override if needed/possible
         """
+        return self.get_connection_data().total_count
 
-        return None
-
-    def get_paged_data(self) -> PagedResult:
+    def get_connection_data(self) -> ConnectionData:
         """
-        Cache to avoid multiple calls to the backend :meth:`_get_paged_result`
-        return a PagedResult object
+        Cache to avoid multiple calls to the backend :meth:`_get_connection_data`
         """
-        if self._paged_data is None:
+        if self._connection_data is None:
             # FIXME, make this call async (not for v1)
-            self._paged_data = self._get_paged_result()
-        return self._paged_data
+            self._connection_data = self._get_connection_data()
+        return self._connection_data
 
     @abstractmethod
-    def _get_paged_result(self):
+    def _get_connection_data(self) -> ConnectionData:
         """
-        Override for desired behaviour
-        return a PagedResult object
+        Override to fetch data
         """
         # FIXME, make this call async (not for v1)
-        return None
 
-    def _get_after_arg(self) -> str:
+    def _get_after_arg(self):
         """
         Return the decoded next page token. Override to support a different
         cursor type
@@ -137,3 +148,42 @@ class BaseConnection(ABC):
         offset_index = self._get_after_arg() or "0"
         index_cursor = int(offset_index) + index
         return utils.get_encoded_cursor(str(index_cursor))
+
+
+class BaseList(ABC):
+    """
+    Base class to be used for simple lists that do not require
+    pagination; eg resolveSWHID entrypoint
+    """
+
+    _node_class: Optional[Type[BaseNode]] = None
+
+    def __init__(self, obj, info, results=None, **kwargs):
+        self.obj: Optional[BaseNode] = obj
+        self.info: GraphQLResolveInfo = info
+        self.kwargs = kwargs
+        self._results: List = results
+
+        self.archive = Archive()
+
+    def get_results(self) -> Optional[List[Any]]:
+        if self._results is None:
+            # To avoid multiple calls to the backend
+            self._results = self._get_results()
+
+        if self._node_class is not None:
+            # convert list items to node objects
+            return [
+                self._node_class(
+                    obj=self.obj, info=self.info, node_data=result, **self.kwargs
+                )
+                for result in self._results
+            ]
+        return self._results
+
+    @abstractmethod
+    def _get_results(self) -> Optional[List]:
+        """
+        Override for desired behaviour
+        return a list of objects
+        """
